"""pymirror"""
from .config import *
from .pymirror import PyMirror
from .cli import *

__version__ = '0.2.7'
__description__ = 'Upload files to multiple free hosting servers'
